@@ -1,9 +1,11 @@
-package Dist::Zilla::Plugin::DistINI 6.015;
+package Dist::Zilla::Plugin::DistINI 6.036;
 # ABSTRACT: a plugin to add a dist.ini to newly-minted dists
 
 use Moose;
 with qw(Dist::Zilla::Role::FileGatherer);
 
+use Dist::Zilla::Pragmas;
+
 use Dist::Zilla::File::FromCode;
 
 use MooseX::Types::Moose qw(ArrayRef Str);
@@ -116,7 +118,7 @@ Dist::Zilla::Plugin::DistINI - a plugin to add a dist.ini to newly-minted dists
 
 =head1 VERSION
 
-version 6.015
+version 6.036
 
 =head1 DESCRIPTION
 
@@ -128,6 +130,19 @@ minting facilities improve.  For example, it will not specify any plugins.
 
 In the meantime, you may be happier with a F<dist.ini> template.
 
+=head1 PERL VERSION
+
+This module should work on any version of perl still receiving updates from
+the Perl 5 Porters.  This means it should work on any version of perl
+released in the last two to three years.  (That is, if the most recently
+released version is v5.40, then this module should work on both v5.40 and
+v5.38.)
+
+Although it may work on older versions of perl, no guarantee is made that the
+minimum required version will not be increased.  The version may be increased
+for any reason, and there is no promise that patches will be accepted to
+lower the minimum required perl.
+
 =head1 ATTRIBUTES
 
 =head2 append_file
@@ -160,11 +175,11 @@ like this:
 
 =head1 AUTHOR
 
-Ricardo SIGNES 😏 <rjbs@cpan.org>
+Ricardo SIGNES 😏 <cpan@semiotic.systems>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2020 by Ricardo SIGNES.
+This software is copyright (c) 2025 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
